"""DSM 6 SYNO.API.Info data."""

DSM_6_API_INFO = {
    "data": {
        "SYNO.API.Auth": {"maxVersion": 6, "minVersion": 1, "path": "auth.cgi"},
        "SYNO.API.Encryption": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "encryption.cgi",
        },
        "SYNO.API.Info": {"maxVersion": 1, "minVersion": 1, "path": "query.cgi"},
        "SYNO.API.OTP": {"maxVersion": 1, "minVersion": 1, "path": "otp.cgi"},
        "SYNO.AudioPlayer": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AudioPlayer.Stream": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App.Backup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App.Restore": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Config.Backup": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Config.Restore": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Service.NetworkBackup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Service.TimeBackup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ACL": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppNotify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal.AccessControl": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal.ReverseProxy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPriv": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPriv.App": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPriv.Rule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.BandwidthControl": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.BandwidthControl.Protocol": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.BandwidthControl.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Cache": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Policy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.ServerInfo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Token": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.CRT": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.CSR": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.LetsEncrypt": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.LetsEncrypt.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.Service": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CurrentConnection": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.ExtIP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.Provider": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.Record": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.Synology": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.TWNIC": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DSMNotify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DataCollect": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DataCollect.Application": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.Defs": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.Initdata": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.JSUIString": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.SessionData": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.Timeout": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.UIString": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Azure.SSO": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain.ADHealthCheck": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain.Conf": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain.Schedule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.BaseDN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.Login.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.WebSphere.SSO": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.EventScheduler": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Bluetooth": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Bluetooth.Device": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Bluetooth.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.DefaultPermission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.BonjourSharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.Driver": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.Network.Host": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.OAuth": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.USB": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.EUnit": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.USB": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.eSATA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.UPS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.EzInternet": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Factory.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Factory.Manutild": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.File.Thumbnail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.AFP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP.ChrootUser": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP.SFTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP.Security": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.AdvancedSetting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.IDMap": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.Kerberos": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.SharePrivilege": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.ReflinkCopy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.Rsync.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.SMB": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.ServiceDiscovery": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.ServiceDiscovery.WSTransfer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Findhost": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group.ExtraAdmin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group.Member": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group.ValidLocalAdmin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.GroupSettings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.BeepControl": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.DCOutput": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.DCOutput.Task": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.FanSpeed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.Hibernation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.LCM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.Led.Brightness": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.MemoryLayout": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.NeedReboot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.PowerRecovery": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.PowerSchedule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.SpectreMeltdown": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.VideoTranscoding": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.ZRAM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Help": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.LUN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Lunbkp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Node": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Replication": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Target": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.VLUN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.IndexFolder": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.MediaConverter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.MobileEnabled": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.ThumbnailQuality": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter.Purchase": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Authentication": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Authentication.Cert": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Bond": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Bridge": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.DHCPServer": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.DHCPServer.ClientList": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.DHCPServer.PXE": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.DHCPServer.Reservation": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.DHCPServer.Vendor": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.DHCPServer.WPAD": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Ethernet": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.IPv6": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.IPv6.Router": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.IPv6.Router.Prefix": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.IPv6Tunnel": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Interface": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.LocalBridge": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.MACClone": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.OVS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.PPPoE": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.PPPoE.Relay": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Proxy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.ConnectionList": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.CountryCode": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.DMZ": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.Gateway.List": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.LocalLan": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.MacFilter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.ParentalControl": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.PkgList": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.PortForward": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.Static.Route": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.Topology": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.TrafficControl.RouterRules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.TrafficControl.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.UPnPServer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.USBModem": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.L2TP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPN.CA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPNWithConf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPNWithConf.Certs": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.PPTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.WOL": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Wifi.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Wifi.Hotspot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Wifi.WPS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.NormalUser": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.NormalUser.LoginNotify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.CustomizedData": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.FilterSettings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.Variables": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.WarningPercentage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.CMS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.CMS.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail.Auth": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.AuthToken": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.Mobile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.SMS": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.SMS.Conf": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.SMS.Provider": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OAuth.Scope": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OAuth.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP.Admin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP.EnforcePolicy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Control": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.FakeIFrame": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Feed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Feed.Keyring": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Installation": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Installation.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.MyDS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.MyDS.Purchase": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Screenshot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Screenshot.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Server": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Setting.Update": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Setting.Volume": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Term": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Thumb": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Uninstallation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Device": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Event": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Filter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.android": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.iOS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.windows": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalSettings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PhotoViewer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Polling.Data": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.Compatibility": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.RouterConf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.RouterInfo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.RouterList": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.Rules.Serv": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.UserDataCollector": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect.Permission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect.Upnp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickStart.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickStart.Install": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Quota": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.RecycleBin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.RecycleBin.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.Language": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.NTP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.NTP.DateTimeFormat": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.NTP.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Analyzer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Analyzer.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Analyzer.Share": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.History": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Redirect": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Util": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SNMP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.AutoBlock": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.AutoBlock.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DSM": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DSM.Embed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DSM.Proxy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DoS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Adapter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Geoip": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Profile.Apply": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Rules.Serv": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.VPNPassthrough": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.VPNPassthrough.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SecurityScan.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SecurityScan.Operation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SecurityScan.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Service": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Service.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Service.PortInfo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Crypto": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Crypto.Key": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.CryptoFile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.AutoKey": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.Key": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.MachineKey": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.Store": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Migration": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Migration.Task": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Permission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Snapshot": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing.Initdata": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing.Login": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing.Session": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.Device": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.Trusted": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.Untrusted": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.Disk": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.Pool": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.Volume": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.iSCSILUN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.iSCSITargets": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.iSCSIUtils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SupportForm.Form": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SupportForm.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SupportForm.Service": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Synohdpack": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.FileTransfer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.PersonalActivity": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.Setting.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.Process": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.ProcessGroup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.ResetButton": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.Utilization": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.TFTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.TaskScheduler": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Terminal": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.AppPortalLogin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.Desktop": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.FileSharingLogin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.Image": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.Login": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.TrustDevice": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Tuned": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.UISearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.AutoUpgrade": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Group.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Group.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.GroupInstall": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.GroupInstall.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Patch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.PreCheck": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Server": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Server.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Setting": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.Home": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordConfirm": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordExpiry": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordMeter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordPolicy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.UserSettings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Virtualization.Host.Capability": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.DSM": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.DSM.External": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.Security.HTTPCompression": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.Security.TLSProfile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DR.Node": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DR.Node.Credential": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DR.Node.Session": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.FindMe": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.Info": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.Network": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.PortEnable": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.PushNotification": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DisasterRecovery.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DisasterRecovery.Retention": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Container": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Container.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Container.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Container.Resource": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.DDSM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.DDSM.Image": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.DDSM.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.DDSM.Network.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.DDSM.Restore": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.DDSM.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.DDSM.Update": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Image": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.License": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Docker.Registry": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation.BTSearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/btsearch.cgi",
        },
        "SYNO.DownloadStation.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "DownloadStation/info.cgi",
        },
        "SYNO.DownloadStation.RSS.Feed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/RSSfeed.cgi",
        },
        "SYNO.DownloadStation.RSS.Site": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/RSSsite.cgi",
        },
        "SYNO.DownloadStation.Schedule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/schedule.cgi",
        },
        "SYNO.DownloadStation.Statistic": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/statistic.cgi",
        },
        "SYNO.DownloadStation.Task": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "DownloadStation/task.cgi",
        },
        "SYNO.DownloadStation2.BTSearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Captcha": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Package.Info": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Package.Module": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Package.Service": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.RSS.Feed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.RSS.Filter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.RSS.Item": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.BT": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.BTSearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Emule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Emule.Location": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.FileHosting": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.FtpHttp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Global": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Location": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Nzb": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Rss": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Scheduler": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT.Peer": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT.Tracker": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.List": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.List.Polling": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.NZB.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.NZB.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.Source": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.Statistic": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.eMule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Thumbnail": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.eMule.Search": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.eMule.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Entry.Request": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Entry.Request.Polling": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.BackgroundTask": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CheckExist": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CheckPermission": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Compress": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CopyMove": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CreateFolder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Delete": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.DirSize": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.External.GoogleDrive": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Extract": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Favorite": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.FormUpload": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.List": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.MD5": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Mount": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Mount.List": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property.ACLOwner": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property.CompressSize": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property.Mtime": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Rename": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Search": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Search.History": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Sharing": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Sharing.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Snapshot": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Thumb": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Timeout": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.UIString": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Upload": {
            "maxVersion": 3,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.UserGrp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.Connection": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.GDrive": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.Protocol": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VirtualFolder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.AppIndexing.Search": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Bookmark": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Elastic.SearchHistory": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Elastic.Spotlight": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Elastic.Term": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.File.Cover": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.File.Thumbnail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Folder": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Highlight": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Indicate": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Search": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Term": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Preference": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.UserGrp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FolderSharing.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FolderSharing.List": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FolderSharing.Thumb": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.License.HA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Client.CA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.History": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.RecvRule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Setting.Storage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Common": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Token": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Package": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.PersonMailAccount": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.PersonMailAccount.Contacts": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.PersonMailAccount.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ResourceMonitor.EventRule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ResourceMonitor.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ResourceMonitor.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Client.Job": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Server.Pair": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf.Checklist": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf.Checklist.Alert": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf.Location": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.LoginActivity": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Report": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Report.HTML": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Snap.Usage.Share": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Check": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.DualEnclosure": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Enclosure": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Flashcache": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.HddMan": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Pool": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Smart": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Smart.Scheduler": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Spare": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Spare.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Storage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Volume": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VideoPlayer.Subtitle": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VideoPlayer.SynologyDrive.Subtitle": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
    },
    "success": True,
}



"""DSM Information data."""

from __future__ import annotations

import re
from typing import TypedDict

from awesomeversion import AwesomeVersion

from synology_dsm.api import SynoBaseApi
from synology_dsm.exceptions import SynologyDSMException


class DsmInformationDataType(TypedDict, total=False):
    """Data type."""

    model: str
    ram: int
    serial: str
    temperature: int
    temperature_warn: bool
    uptime: int
    version: str
    version_string: str


class SynoDSMInformation(SynoBaseApi[DsmInformationDataType]):
    """Class containing Information data."""

    API_KEY = "SYNO.DSM.Info"

    async def update(self) -> None:
        """Updates information data."""
        raw_data = await self._dsm.get(self.API_KEY, "getinfo")
        if isinstance(raw_data, dict) and (data := raw_data.get("data")) is not None:
            self._data = data

    @property
    def model(self) -> str:
        """Model of the NAS."""
        return self._data["model"]

    @property
    def ram(self) -> int:
        """RAM of the NAS (in MB)."""
        return self._data["ram"]

    @property
    def serial(self) -> str:
        """Serial of the NAS."""
        return self._data["serial"]

    @property
    def temperature(self) -> int | None:
        """Temperature of the NAS."""
        return self._data.get("temperature")

    @property
    def temperature_warn(self) -> bool:
        """Temperature warning of the NAS."""
        # some very old nas may not provide this attribute
        return self._data.get("temperature_warn", False)

    @property
    def uptime(self) -> int:
        """Uptime of the NAS."""
        return self._data["uptime"]

    @property
    def version(self) -> str:
        """Version of the NAS (build version)."""
        return self._data["version"]

    @property
    def version_string(self) -> str:
        """Version of the NAS."""
        return self._data["version_string"]

    @property
    def awesome_version(self) -> AwesomeVersion:
        """Awesome version representation."""
        pattern = (
            r"DSM (?P<major>\d+)\.(?P<minor>\d+)"
            r"(\.(?P<micro>\d+))?-(?P<buildnumber>\d+)"
            r"( Update (?P<smallfixnumber>\d+))?"
        )
        match = re.match(pattern, self.version_string)
        if not match:
            raise SynologyDSMException(
                api=self.API_KEY,
                code=0,
                details=f"Could not parse version string {self.version_string}",
            )
        parts = match.groupdict()
        version = f"{parts['major']}.{parts['minor']}.{parts['micro'] or '0'}"
        if (smallfixnumber := parts.get("smallfixnumber")) is not None:
            version += f".{smallfixnumber}"

        return AwesomeVersion(version)



"""VirtualMachineManager guest."""

from __future__ import annotations

from typing import TypedDict, Union

SynoVmmGuestData = TypedDict(
    "SynoVmmGuestData",
    {
        "autorun": int,
        "desc": str,
        "guest_id": str,
        "name": str,
        "ram_used": int,
        "status": str,
        "vcpu_num": int,
        "vcpu_usage": Union[str, int],  # empty str when offline
        "vram_size": int,
    },
    total=False,
)


class SynoVmmGuest:
    """An representation of a Synology Virtual Machine Manager guest."""

    def __init__(self, data: SynoVmmGuestData) -> None:
        """Initialize a Virtual Machine Manager guest."""
        self._data: SynoVmmGuestData = data

    def update(self, data: SynoVmmGuestData) -> None:
        """Update the vmm guest."""
        self._data = data

    @property
    def autorun(self) -> bool:
        """Return autorun of the vmm guest."""
        return bool(self._data["autorun"])

    @property
    def description(self) -> str:
        """Return description of the vmm guest."""
        return self._data["desc"]

    @property
    def guest_id(self) -> str:
        """Return guest_id of the vmm guest."""
        return self._data["guest_id"]

    @property
    def name(self) -> str:
        """Return name of the vmm guest."""
        return self._data["name"]

    @property
    def status(self) -> str:
        """Return status of the vmm guest."""
        return self._data["status"]

    @property
    def host_cpu_usage(self) -> int:
        """Return host cpu usage in one thousandth of the vmm guest."""
        if isinstance(self._data["vcpu_usage"], str):
            return 0
        return self._data["vcpu_usage"]

    @property
    def host_ram_usage(self) -> int:
        """Return host ram usage in KiByte of the vmm guest."""
        return self._data["ram_used"]

    @property
    def vcpu_num(self) -> int:
        """Return number of vcpu of the vmm guest."""
        return self._data["vcpu_num"]

    @property
    def vram_size(self) -> int:
        """Return size of vram in KiByte of the vmm guest."""
        return self._data["vram_size"]



"""DSM 6 SYNO.API.Auth data."""

from tests.const import (
    DEVICE_TOKEN,
    ERROR_AUTH_OTP_NOT_SPECIFIED,
    SESSION_ID,
    SYNO_TOKEN,
)

DSM_6_AUTH_LOGIN = {
    "data": {"is_portal_port": False, "sid": SESSION_ID, "synotoken": SYNO_TOKEN},
    "success": True,
}
DSM_6_AUTH_LOGIN_2SA = ERROR_AUTH_OTP_NOT_SPECIFIED
DSM_6_AUTH_LOGIN_2SA_OTP = {
    "data": {
        "did": DEVICE_TOKEN,
        "is_portal_port": False,
        "sid": SESSION_ID,
        "synotoken": SYNO_TOKEN,
    },
    "success": True,
}

DSM_6_AUTH_LOGOUT = {"success": True}
